@@ -191,6 +191,17 @@ search_finish (GucharmapSearchDialog *search_dialog,
   g_simple_action_set_enabled (G_SIMPLE_ACTION (action), TRUE);
 }
 
+static void
+ensure_search_dialog (GucharmapWindow *guw)
+{
+  if (guw->search_dialog == NULL)
+    {
+      guw->search_dialog = gucharmap_search_dialog_new (guw);
+      g_signal_connect (guw->search_dialog, "search-start", G_CALLBACK (search_start), guw);
+      g_signal_connect (guw->search_dialog, "search-finish", G_CALLBACK (search_finish), guw);
+    }
+}
+
 static void
 search_find (GSimpleAction *action,
              GVariant      *parameter,
@@ -200,16 +211,12 @@ search_find (GSimpleAction *action,
 
   g_assert (GUCHARMAP_IS_WINDOW (guw));
 
-  if (guw->search_dialog == NULL)
-    {
-      guw->search_dialog = gucharmap_search_dialog_new (guw);
-      g_signal_connect (guw->search_dialog, "search-start", G_CALLBACK (search_start), guw);
-      g_signal_connect (guw->search_dialog, "search-finish", G_CALLBACK (search_finish), guw);
-    }
+  ensure_search_dialog (guw);
 
   gucharmap_search_dialog_present (GUCHARMAP_SEARCH_DIALOG (guw->search_dialog));
 }
 
+
 static void
 search_find_next (GSimpleAction *action,
                   GVariant      *parameter,
@@ -408,6 +415,7 @@ help_about (GSimpleAction *action,
       "Daniel Elstner <daniel.elstner@gmx.net>", 
       "Padraig O'Briain <Padraig.Obriain@sun.com>",
       "Christian Persch <" "chpe" "\100" "gnome" "." "org" ">",
+      "DaeHyun Sung <sungdh86@gmail.com>",
       NULL 
     };
 
@@ -446,10 +454,11 @@ help_about (GSimpleAction *action,
   gtk_show_about_dialog (GTK_WINDOW (guw),
 			 "program-name", _("GNOME Character Map"),
 			 "version", VERSION,
-			 "comments", _("Based on the Unicode Character Database 7.0.0"),
+			 "comments", _("Based on the Unicode Character Database 10.0.0"),
 			 "copyright", "Copyright © 2004 Noah Levitt\n"
-				      "Copyright © 1991–2014 Unicode, Inc.\n"
-				      "Copyright © 2007–2013 Christian Persch",
+				      "Copyright © 1991–2017 Unicode, Inc.\n"
+				      "Copyright © 2007–2017 Christian Persch\n"
+                                      "Copyright © 2016 DaeHyun Sung",
 			 "documenters", documenters,
 			 "license", license_trans,
 			 "wrap-license", TRUE,
@@ -763,12 +772,6 @@ gucharmap_window_init (GucharmapWindow *guw)
                                    menu_entries, G_N_ELEMENTS (menu_entries),
                                    guw);
 
-  /* snap-to-power-of-two */
-  action = g_settings_create_action (guw->settings, "snap-cols-pow2");
-  g_action_map_add_action (G_ACTION_MAP (guw), action);
-  g_signal_connect (guw->settings, "changed::snap-cols-pow2",
-                    G_CALLBACK (snap_cols_pow2_changed), guw);
-
   /* Now the widgets */
   grid = gtk_grid_new ();
   gtk_container_add (GTK_CONTAINER (guw), grid);
@@ -829,6 +832,13 @@ gucharmap_window_init (GucharmapWindow *guw)
 
   gtk_window_set_has_resize_grip (GTK_WINDOW (guw), TRUE);
 
+  /* snap-to-power-of-two */
+  action = g_settings_create_action (guw->settings, "snap-cols-pow2");
+  g_action_map_add_action (G_ACTION_MAP (guw), action);
+  snap_cols_pow2_changed (guw->settings, "snap-cols-pow2", guw);
+  g_signal_connect (guw->settings, "changed::snap-cols-pow2",
+                    G_CALLBACK (snap_cols_pow2_changed), guw);
+
   /* read initial settings */
   /* font */
   g_settings_get (guw->settings, "font", "ms", &font);
@@ -875,28 +885,11 @@ gucharmap_window_finalize (GObject *object)
   G_OBJECT_CLASS (gucharmap_window_parent_class)->finalize (object);
 }
 
-static GObject *
-gucharmap_window_constructor (GType                  type,
-                              guint                  n_construct_properties,
-                              GObjectConstructParam *construct_params)
-{
-  GObject *object;
-
-  object = G_OBJECT_CLASS (gucharmap_window_parent_class)->constructor (type, n_construct_properties, construct_params);
-  g_object_bind_property (gtk_settings_get_default (),
-                          "gtk-shell-shows-app-menu",
-                          object, "show-menubar",
-                          G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE | G_BINDING_INVERT_BOOLEAN);
-
-  return object;
-}
-
 static void
 gucharmap_window_class_init (GucharmapWindowClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  object_class->constructor = gucharmap_window_constructor;
   object_class->finalize = gucharmap_window_finalize;
 }
 
@@ -926,3 +919,16 @@ gucharmap_window_set_font (GucharmapWindow *guw,
   gucharmap_charmap_set_font_desc (guw->charmap, font_desc);
   pango_font_description_free (font_desc);
 }
+
+void
+gucharmap_window_search (GucharmapWindow *guw,
+                         const char *str)
+{
+  g_return_if_fail (GUCHARMAP_IS_WINDOW (guw));
+  g_return_if_fail (str != NULL);
+
+  ensure_search_dialog (guw);
+  gucharmap_search_dialog_set_search (GUCHARMAP_SEARCH_DIALOG (guw->search_dialog), str);
+  gucharmap_search_dialog_start_search (GUCHARMAP_SEARCH_DIALOG (guw->search_dialog),
+                                        GUCHARMAP_DIRECTION_FORWARD);
+}
